=======================
Contribution Guidelines
=======================

In the Contributions Guide, you will find documented policies for
developing with monasca-events-api. This includes the processes we use for
blueprints and specs, bugs, contributor on boarding, core reviewer
memberships, and other procedural items.

monasca-events-api, as with all OpenStack projects, is written with the
following design guidelines in mind:

* **Component based architecture**: Quickly add new behaviors
* **Highly available**: Scale to very serious workloads
* **Fault tolerant**: Isolated processes avoid cascading failures
* **Recoverable**: Failures should be easy to diagnose, debug, and rectify
* **Open standards**: Be a reference implementation for a community-driven api

This documentation is generated by the Sphinx toolkit and lives in the source
tree. Additional documentation on monasca-events-api and other components of
OpenStack can be found on the `OpenStack wiki <http://wiki.openstack.org>`_.

Developer reference
-------------------

.. toctree::
   :maxdepth: 1

   code
